System-provided Widget library.
| base_widget | This is a base Widget that draws a background and a box with colors, based on the settings
in the properties. Custom Widgets can use the BaseWidget as a top-level widget for drawing
a background or the bounding box, extending it later.
|
| button_widget | This is a Widget that provides button functionality.
|
| checkbox_widget | This is a Widget that shows a checkbox, indicating an "X" inside the box when selected,
and a blank box otherwise.
|
| grid_widget | This is a Widget that draws a grid inside the body of the Widget.
|
| group_box_widget | This is a Widget that draws a grouping box.
|
| image_button_widget | This is a Widget that acts as a ButtonWidget, but with an image.
|
| image_widget | This is an image Widget that draws an image (in any of the supported image formats that SDL2 provides).
|
| progress_widget | This is a Widget that can be used to show a progress bar.
|
| text_widget | This is a text Widget that draws text given a style, justification, font name, size, and
body of text.
|
| toggle_button_widget | This is a Widget that can be selected/toggled on or off.
|