[−][src]Module pushrod_widgets::widget
This is the Widget trait that all drawable Widgets use. Any special functionality should
be defined using interactions with properties. Widgets can decide whether or not to set
themselves in invalidated state after a property value changes, which indicates to the
top-level drawing loop whether or not a Widget needs to be redrawn.
Traits
| Widget | This is the |