[−][src]Enum pushrod_widgets::event::PushrodEvent
These are the events that are generated by the Pushrod Event translation system for SDL2.
These events are passed into the handle_event function, which contains the currently
translated events.
Variants
Mouse movement detected, coordinates are relative to the X/Y position within the widget, not
to the Window in which it belongs.
Fields of MouseMoved
Mouse wheel scrolled.
Fields of MouseScrolled
Mouse button click/release.
Fields of MouseButton
Event (draw tick) that is issued between drawing frames. This can be used as a timer.
Fields of DrawFrame
timestamp: u128Widget was clicked.
Fields of WidgetClicked
Widget was selected.
Fields of WidgetSelected
Widget state was toggled.
Fields of WidgetToggled
Widget radio button state was selected.
Widget radio button state was unselected.
Mouse entered the scope of a widget.
Fields of WidgetMouseEntered
widget_id: u32The Widget ID.
Mouse exited the scope of a widget.
Fields of WidgetMouseExited
widget_id: u32The Widget ID.
Widget gained focus through a [TAB] key, or other means.
Fields of WidgetFocusGained
widget_id: u32The Widget ID.
Widget lost focus.
Fields of WidgetFocusLost
widget_id: u32The Widget ID.
Tab was selected inside a Tab Widget object.
Fields of WidgetTabSelected
Indicates that a value contained within a Widget was altered.
Fields of WidgetValueChanged
Indicates a Widget's position was altered within the bounds of the Window.
Fields of WidgetMoved
Indicates that the visibility of a Widget on the screen has physically changed.
This is an indication of the visibility based on its alpha value. An alpha value
of 100 indicates that the object is completely visible, whereas an alpha of 0
indicates that it is hidden.
Fields of WidgetVisibilityChanged
widget_id: u32The Widget ID.
alpha: u32The Widget's visible alpha value: 0 to 100.
Indicates whether or not the Widget has disappeared from the Window. This can
be set to true or false, even if the alpha value is greater than 0. If the value is
set true, it means the object is not visible. false otherwise. If the alpha is
0, and hidden is false, it will still indicate a visibility of 0, which will mean
the object cannot be interacted with.